#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.dublincore.interfaces import IZopeDublinCore

from pyams_content_es.interfaces import IDocumentIndexInfo
from pyams_utils.adapter import adapter_config
from pyams_workflow.interfaces import IWorkflowInfo, IWorkflowPublicationInfo, IWorkflowPublicationSupport, \
    IWorkflowState


@adapter_config(name='workflow', context=IWorkflowPublicationSupport, provides=IDocumentIndexInfo)
def workflow_managed_content_index_info(content):
    """Workflow managed content index info"""
    dc_info = IZopeDublinCore(content)
    result = {
        'created_date': dc_info.created,
        'modified_date': dc_info.modified
    }
    workflow_info = IWorkflowInfo(content, None)
    if workflow_info is not None:
        result.update({'name': workflow_info.name})
    workflow_pub_info = IWorkflowPublicationInfo(content, None)
    if workflow_pub_info is not None:
        result.update({
            'publication_date': workflow_pub_info.publication_date,
            'effective_date': workflow_pub_info.publication_effective_date,
            'push_end_date': workflow_pub_info.push_end_date,
            'expiration_date': workflow_pub_info.publication_expiration_date,
            'first_publication_date': workflow_pub_info.first_publication_date,
            'visible_publication_date': workflow_pub_info.visible_publication_date
        })
    workflow_state = IWorkflowState(content, None)
    if workflow_state is not None:
        result.update({
            'status': workflow_state.state,
            'date': workflow_state.state_date,
        })
    return {'workflow': result}
